<template>
  <div class="ai-editor-container">
    <div ref="editorRef" :style="{ height }" />
  </div>
</template>

<script>
import { AiEditor } from "aieditor";
import 'aieditor/dist/style.css'

export default {
  name: 'AiEditor',
  props: {
    value: {
      type: String,
      default: ''
    },
    height: {
      type: String,
      default: '500px'
    },
    placeholder: {
      type: String,
      default: '请输入内容...'
    },
    readOnly: {
      type: Boolean,
      default: false
    },
    toolbar: {
      type: Array,
      default: () => [
        'bold',
        'italic',
        'underline',
        'strikethrough',
        'heading',
        'quote',
        'code',
        'list',
        'ordered-list',
        'unordered-list',
        'link',
        'image',
        'table'
      ]
    }
  },
  data() {
    return {
      editor: null
    }
  },
  watch: {
    value: {
      handler(newVal) {
        if (this.editor && newVal !== this.editor.getHtml()) {
          this.editor.setContent(newVal)
        }
      },
      immediate: true
    },
    readOnly: {
      handler(newVal) {
        console.log('readOnly', newVal)
        if (this.editor) {
          this.editor.setReadOnly(newVal)
        }
      },
      immediate: true
    }
  },
  mounted() {
    this.initEditor()
  },
  beforeDestroy() {
    this.destroyEditor()
  },
  methods: {
    initEditor() {
      const options = {
        element: this.$refs.editorRef,
        placeholder: this.placeholder,
        content: this.value,
        editable: !this.readOnly,
        toolbar: this.toolbar,
        toolbarExcludeKeys: ["ai"],
        draggable: false,
        onChange: (content) => {
          this.$emit('input', content)
          this.$emit('change', content)
        },
        onFocus: () => {
          this.$emit('focus')
        },
        onBlur: () => {
          this.$emit('blur')
        },
        // 禁用 AI 功能
        ai: false,
        // 禁用调整大小功能
        resize: false,
        // 添加唯一标识
        id: `editor-${Date.now()}-${Math.random().toString(36).substr(2, 9)}`
      }

      try {
        this.editor = new AiEditor(options)
      } catch (error) {
        console.error('Failed to initialize AiEditor:', error)
      }
    },
    destroyEditor() {
      if (this.editor) {
        this.editor.destroy()
        this.editor = null
      }
    },
    // 获取编辑器内容
    getContent() {
      return this.editor ? this.editor.getHtml() : ''
    },
    // 设置编辑器内容
    setContent(content) {
      if (this.editor) {
        this.editor.setContent(content)
      }
    },
    // 清空编辑器内容
    clear() {
      if (this.editor) {
        this.editor.setContent('')
      }
    },
    // 获取编辑器实例
    getEditor() {
      return this.editor
    }
  }
}
</script>

<style scoped>
:deep(aie-footer) {
  display: none !important;
}

.ai-editor-container {
  width: 100%;
  border-radius: 4px;
  background: #fff;
}

#editor {
  width: 100%;
  min-height: 300px;
}

:deep(.ai-editor) {
  border: none !important;
}

:deep(.ai-editor-toolbar) {
  border-bottom: 1px solid #dcdfe6 !important;
}

:deep(.ai-editor-content) {
  border: none !important;
}

/* 隐藏右下角拖动图标 */
:deep(.ai-editor-resize) {
  display: none !important;
}

/* 隐藏 AI 相关按钮 */
:deep(.ai-editor-ai-button) {
  display: none !important;
}
</style>